@@ -35,23 +35,11 @@ pub trait AsyncIOBuf {
     type StreamR: AsyncRead + AsyncWrite + Unpin;
     type StreamW: AsyncRead + AsyncWrite + Unpin;
 
-    fn poll_read_buf(
-        &mut self,
-        cx: &mut Context<'_>,
-        stream: &mut Self::StreamR,
-    ) -> Poll<Result<usize>>;
+    fn poll_read_buf(&mut self, cx: &mut Context<'_>, stream: &mut Self::StreamR) -> Poll<Result<usize>>;
 
-    fn poll_write_buf(
-        &mut self,
-        cx: &mut Context<'_>,
-        stream: &mut Self::StreamW,
-    ) -> Poll<Result<usize>>;
+    fn poll_write_buf(&mut self, cx: &mut Context<'_>, stream: &mut Self::StreamW) -> Poll<Result<usize>>;
 
-    fn poll_flush_buf(
-        &mut self,
-        cx: &mut Context<'_>,
-        stream: &mut Self::StreamW,
-    ) -> Poll<Result<()>>;
+    fn poll_flush_buf(&mut self, cx: &mut Context<'_>, stream: &mut Self::StreamW) -> Poll<Result<()>>;
 }
 
 impl<B, SR, SW> CopyBuffer<B, SR, SW>
@@ -115,10 +103,7 @@ where
             // If pos larger than cap, this loop will never stop.
             // In particular, user's wrong poll_write implementation returning
             // incorrect written length may lead to thread blocking.
-            debug_assert!(
-                self.pos <= self.cap,
-                "writer returned length larger than input slice"
-            );
+            debug_assert!(self.pos <= self.cap, "writer returned length larger than input slice");
 
             // If we've written all the data and we've seen EOF, flush out the
             // data and finish the transfer.
